<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Fcitx::AdvancedSettingWidget</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="105"/>
        <source>Global Config</source>
        <translation>Celkové nastavení</translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="108"/>
        <source>Add-ons</source>
        <translation>Doplňky</translation>
    </message>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="391"/>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>FcitxConfigPlugin</name>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="69"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="81"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="109"/>
        <location filename="../src/fcitxconfigplugin.cpp" line="117"/>
        <source>Input Methods</source>
        <translation>Vstupní metody</translation>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="75"/>
        <source>Keyboard and Language</source>
        <translation>Klávesnice a jazyk</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="82"/>
        <source>Manage Input Methods</source>
        <translation>Spravovat vstupní metody</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="83"/>
        <source>Switch input methods</source>
        <translation>Přepnout vstupní metody</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="84"/>
        <source>Switch to the first input method</source>
        <translation>Přepnout na první vstupní metodu</translation>
    </message>
    <message>
        <location filename="../src/fcitxconfigplugin.cpp" line="85"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
    </message>
</context>
<context>
    <name>FcitxSettingsHead</name>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="51"/>
        <location filename="../src/widgets/settingshead.cpp" line="135"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../src/widgets/settingshead.cpp" line="137"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
</context>
<context>
    <name>IMAddWindow</name>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="62"/>
        <source>Add Input Method</source>
        <translation>Přidat vstupní metodu</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="70"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="80"/>
        <source>Find more in App Store</source>
        <translation>Najít více v katalogu aplikací</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="86"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../src/window/imaddwindow.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>IMSettingWindow</name>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="115"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="119"/>
        <source>Switch between the current/first input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="122"/>
        <location filename="../src/window/imsettingwindow.cpp" line="125"/>
        <source>Restore Defaults</source>
        <translation>Vrátit na výchozí hodnoty</translation>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="129"/>
        <source>Advanced Settings</source>
        <translation>Pokročilá nastavení</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="139"/>
        <source>Manage Input Methods</source>
        <translation>Spravovat vstupní metody</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="149"/>
        <source>Shortcuts</source>
        <translation>Klávesové zkratky</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
    <message>
        <location filename="../src/window/imsettingwindow.cpp" line="166"/>
        <source>Add Input Method</source>
        <translation>Přidat vstupní metodu</translation>
        <extra-child_page>Manage Input Methods</extra-child_page>
        <extra-contents_path>/keyboard/Manage Input Methods</extra-contents_path>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/window/advancedsettingwidget.cpp" line="585"/>
        <location filename="../src/window/advancedsettingwidget.cpp" line="637"/>
        <source>None</source>
        <translation>Žádná</translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxCheckBoxSettingsItem</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="599"/>
        <source>Configure</source>
        <translation>Nastavit</translation>
    </message>
</context>
<context>
    <name>dcc_fcitx_configtool::widgets::FcitxKeyLabelWidget</name>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="47"/>
        <location filename="../src/widgets/keysettingsitem.cpp" line="166"/>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <location filename="../src/widgets/keysettingsitem.cpp" line="53"/>
        <source>Enter a new shortcut</source>
        <translation>Zadejte novou zkratku</translation>
    </message>
</context>
</TS>
